==> jrack-web-1.0.0-sources.jar: cn/jrack/web/controller/IndexController.java <==
package cn.jrack.web.controller;


import cn.jrack.core.pojo.PageResult;
import cn.jrack.springboot.satoken.core.StUserInfo;
import cn.jrack.springboot.satoken.core.annotation.Ignore;
import cn.jrack.springboot.web.core.util.WebFrameworkUtils;
import cn.jrack.web.entity.Entity;
import cn.jrack.web.entity.User;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@Ignore
@RestController
@RequestMapping
public class IndexController {

    @GetMapping("/index")
    public void index() {
    }

    @GetMapping("/index1")
    public String index1() {
        return "123";
    }

    @GetMapping("/index2")
    public Integer index2() {
        return 123;
    }

    @GetMapping("/index3")
    public PageResult index3() {
        return new PageResult(null, 1000L);
    }


    @GetMapping("/login")
    public void login() {
        WebFrameworkUtils.login(1000L, new StUserInfo());
    }


    @GetMapping
    public User user()
    {
        User user = new User();
        user.setUserType("sex");
        return user;
    }

    @RequestMapping("/test")
    public Entity test(String gender,String identityType){
        return new Entity("张三","中国",gender,identityType);
    }

    @RequestMapping("/tests")
    public List<Entity> tests(String gender, String identityType){
        List<Entity> list=new ArrayList<>();
        list.add(new Entity("张三","中国",gender,identityType));
        list.add(new Entity("李四","中国",gender,identityType));
        return  list;
    }
}

==> jrack-web-1.0.46-sources.jar: cn/jrack/web/controller/IndexController.java <==
package cn.jrack.web.controller;


import cn.jrack.core.pojo.PageResult;
import cn.jrack.springboot.satoken.core.StUserInfo;
import cn.jrack.springboot.satoken.core.annotation.Ignore;
import cn.jrack.springboot.web.core.util.WebFrameworkUtils;
import cn.jrack.web.entity.Entity;
import cn.jrack.web.entity.User;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Ignore
@RestController
@RequestMapping
public class IndexController {

    @GetMapping("/index")
    public void index() {
    }
    @Ignore
    @GetMapping("/index1")
    public LocalDateTime index1() {
        return LocalDateTime.now();
    }
    @Ignore
    @GetMapping("/index2")
    public Integer index2() {
        return 123;
    }

    @GetMapping("/index3")
    public PageResult index3() {
        return new PageResult(null, 1000L);
    }


    @GetMapping("/login")
    public void login() {
        WebFrameworkUtils.login(1000L, new StUserInfo());
    }


    @GetMapping
    public User user()
    {
        User user = new User();
        user.setUserType("sex");
        return user;
    }

    @RequestMapping("/test")
    public Entity test(String gender,String identityType){
        return new Entity("张三","中国",gender,identityType);
    }

    @RequestMapping("/tests")
    public List<Entity> tests(String gender, String identityType){
        List<Entity> list=new ArrayList<>();
        list.add(new Entity("张三","中国",gender,identityType));
        list.add(new Entity("李四","中国",gender,identityType));
        return  list;
    }
}
